@@ -155,6 +155,16 @@ function log_out_of_https_do() {
    }
 
 
+   // need to fix the sq_base_url session varible, since
+   // it is put in the session in redirect.php with
+   // the https protocol before we get here 
+   //
+   global $sq_base_url;
+   compatibility_sqextractGlobalVar('sq_base_url');
+   $sq_base_url = str_replace('https://', 'http://', $sq_base_url);
+   compatibility_sqsession_register($sq_base_url, 'sq_base_url');
+
+  
    if ( ! isset($_SERVER['HTTP']) && $https_logoff_count == 0)
    {
 
@@ -170,8 +180,15 @@ function log_out_of_https_do() {
       compatibility_sqsession_register($https_logoff_count, 'https_logoff_count');
       $location = 'http://' . $originalHost
          . $_SERVER['PHP_SELF'];
+
       displayHtmlHeader('',
          "\n<META HTTP-EQUIV=\"REFRESH\" CONTENT=\"0;URL=$location\">\n");
+
+      // note that this causes a pop-up in some browsers
+      // that notifies you you are leaving a secure site
+      //
+      //header("Location: $location");
+
       exit();
 
    }
